#!/bin/bash

#PBS -l walltime=01:00:00
#PBS -l select=1:ncpus=1:mem=3900mb
#PBS -l place=free:shared

if [[ -z $PBS_O_WORKDIR ]] 
     then cdir=$(dirname "$0")
     else cdir=$PBS_O_WORKDIR
fi
. "$cdir"/common
cdir=$(normalpath "$cdir")  # scripts directory

pn=$0
prog=$(basename "$pn")
comline="$cdir/$prog $*"

bd=$(normalpath $cdir/..)  # base directory
fl=$bd/etc/filelist.csv
atlas=$bd/etc/atlas.csv
maperdir=/home/rh17/software/maper/maper-0.4.1/core  # MAPER software directory
jobs=0  # zero for PBS
ARCH=pbs
type=oldstandard

# Define directories
outdir=$bd/maper   # Destination directory
workdir=$cdir/maper  # Common working directory
debugdir=$cdir/maper/debug  # Debug directory
mkdir -p $debugdir $outdir

cat /dev/null >"$workdir"/job-list.sh
cat $fl | while read tgt
do
    (( m+=1 ))
    tgtname=$(basename $tgt .nii.gz)
    tgtoutdir="$workdir"/"$tgtname"
    mkdir -p "$tgtoutdir" || fatal "Could not create directory $tgtoutdir"
    tgtop="$bd/onepad/$tgt"
    tgttc3="$bd/tc3/$tgt"
    tpn="$bd/posnorm/$tgtname.dof.gz"
    set -- $(grep -v '^#' "$atlas")
    atlasbase="$1" ; shift
    atlases="$*"
    atlasn=$#
    n=0
    for j in $atlases ; do
	(( n+=1 ))
	set -- $(echo $j | tr , ' ')
	atlname="$1" ; shift
	srcop="$atlasbase"/"$1" ; shift
	srctc3="$atlasbase"/"$1" ; shift
	spn="$atlasbase"/"$1" ; shift
	srcsegs=
	while [ $# -gt 0 ] ; do
	    srcsegs="$srcsegs -srcseg $atlasbase/$1" ; shift
	done
	echo "$maperdir"/propagate -source "$srcop" -target "$tgtop" -srctc3 "$srctc3" -tgttc3 "$tgttc3" -spn "$spn" -tpn "$tpn" $srcsegs -type $type -ensemblesize $atlasn -output "$tgtoutdir"/a$n -resultdir "$outdir" -basename "$tgtname" -debug "$debugdir" >>"$workdir"/job-list.sh
	# 
    done
done

echo -n "Waiting for data "
for i in $(cat $fl) ; do until [[ -e $bd/tc3/$i ]] ; do echo -n . ; sleep 5 ; done ; done 
echo ; echo Running

cd "$workdir"
export MAPER_WORKDIR=$workdir
"$maperdir"/distrib -jobs $jobs -processlist "$workdir"/job-list.sh -arch $ARCH 

exit 0
