#!/bin/bash

# reo, originfix, subsample, bias, posnorm-pre

#PBS -l walltime=01:00:00
#PBS -l select=1:ncpus=8:mem=15900mb
#PBS -l place=free:shared

if [[ -z $PBS_O_WORKDIR ]] 
     then cdir=$(dirname "$0")
     else cdir=$PBS_O_WORKDIR
fi
. "$cdir"/common
cdir=$(normalpath "$cdir")

pn=$0
prog=$(basename "$pn")
comline="$cdir/$prog $*"

if [[ $PBS_ARRAY_INDEX -gt 0 ]] 
then
    idx=$PBS_ARRAY_INDEX
    wd=$PBS_O_WORKDIR
else
    idx=$1
    wd=$PWD
fi

td=$(tempdir)
cd $td

bd=$(normalpath $cdir/../)
fl=$bd/etc/filelist.csv

fn=$(head -n $idx $fl | tail -n 1)

export FSLOUTPUTTYPE=NIFTI_GZ

msg $fn
imcp $bd/t1/$fn current
chmod +rw current.nii.gz

## Individual blocks can be disabled

## Block: standardize orientation
mkdir -p reo
fslreorient2std current reo/$fn
test -e reo/$fn || fatal "Failed to create reo/$fn"
imcp reo/$fn current
## End block

## Block: resample
mkdir -p mmiso
resample current.nii.gz template.nii -size 1 1 1 
reg_resample -flo current.nii.gz -ref template.nii -res mmiso/$fn -inter 4 -omp 6
test -e mmiso/$fn || fatal "Failed to create mmiso/$fn"
imcp mmiso/$fn current
## End block

## Block: set origin to {0,0,0}
mkdir -p origin0
headertool current.nii.gz origin0/$fn -origin 0 0 0
test -e origin0/$fn || fatal "Failed to create origin0/$fn"
imcp origin0/$fn current
## End block

## Block: signal inhomogeneity (bias field) correction
mkdir -p n4
echo $LD_LIBRARY_PATH
N4ITKBiasFieldCorrection current.nii.gz n4/$fn
test -e n4/$fn || fatal "Failed to create n4/$fn"
imcp n4/$fn current
## End block

## Block: positional normalization (provisional)
bn=$(basename $fn .nii.gz)
mkdir -p posnorm-pre
$HOME/software/posnorm/posnorm.sh current.nii.gz current.nii.gz posnorm-pre/$bn.dof.gz
## End block

find . -type d | grep -v '^.$' | while read i
do
    mkdir -p $bd/$i
    cp $i/$bn.???.gz $bd/$i/
done





